/*
 * Copyright (C) 2008 Gauvain Pocentek <gpocentek@linutop.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <stdio.h>

#include <gmodule.h>
#include <glib/gprintf.h>
#include <glib/gstdio.h>
#include <gtk/gtk.h>
#include <libxfce4util/libxfce4util.h>
#include <libxfcegui4/libxfcegui4.h>

#include "appstarter.h"

int main (int argc, char *argv[])
{
    GtkWidget *dialog, *chooser;
    gchar *conffile = NULL;

    GOptionEntry options[] = {
        { "conffile", 'c', 0, G_OPTION_ARG_STRING,
          &conffile, N_("Use the specified configuration file"), "FILE" },
        { NULL },
    };

    if (!gtk_init_with_args (&argc, &argv, "", options, PACKAGE, NULL)) {
        g_print ( _(
            "%s:\nTry %s --help to see a full list of available command line options.\n"),
                PACKAGE, PACKAGE_NAME);
        return 1;
    }

    if (! conffile)
        conffile = xfce_get_homefile (".config", "appstarterrc", NULL);

    dialog = gtk_dialog_new_with_buttons("AppStarter",
                                         NULL,
                                         GTK_DIALOG_MODAL,
                                         GTK_STOCK_OK,
                                         GTK_RESPONSE_ACCEPT,
                                         NULL);
    gtk_container_set_border_width (GTK_CONTAINER (dialog), 5);

    chooser = as_chooser_new ((const gchar *) conffile);
    g_free (conffile);
    gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), chooser);
    gtk_widget_show (chooser);

    if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_ACCEPT)
        as_chooser_save (AS_CHOOSER (chooser));

    gtk_widget_destroy (dialog);

    return 0;
}
